@@ -21,13 +21,13 @@
 
 #include <config.h>
 #include <gtk/gtk.h>
-#include <libgnome/libgnome.h>
+#include <canberra-gtk.h>
 
 #include "plugins.h"
 #include "xchat-plugin.h"
 #include "xg-plugin.h"
 
-#define SOUND_NOTIFICATION_VERSION "0.1"
+#define SOUND_NOTIFICATION_VERSION "0.2"
 
 void xchat_plugin_get_info   (char **plugin_name, char **plugin_desc, char **plugin_version, void **reserved);
 int  xchat_plugin_init       (xchat_plugin *plugin_handle, char **plugin_name, char **plugin_desc, char **plugin_version, char *arg);
@@ -41,10 +41,11 @@ static xchat_plugin*       ph;                  /* Plugin handle. */
 static int
 new_msg_cb (char **word, void *msg_lvl)
 {
-	if (g_file_test ("../../data/message.wav", G_FILE_TEST_EXISTS))
-		gnome_sound_play ("../../data/message.wav");
-	else
-		gnome_sound_play (XCHATSHAREDIR "/message.wav");
+	ca_context_play (ca_gtk_context_get (), 0,
+			 CA_PROP_APPLICATION_NAME, _("XChat-GNOME IRC Chat"),
+			 CA_PROP_EVENT_ID, "message-new-instant",
+			 CA_PROP_EVENT_DESCRIPTION, _("New message received"),
+			 NULL);
 	return 0;
 }
 
@@ -74,8 +75,6 @@ xchat_plugin_init (xchat_plugin * plugin_handle, char **plugin_name, char **plug
 {
 	ph = plugin_handle;
 
-	gnome_sound_init ("localhost");
-
 	/* Set the plugin info. */
 	xchat_plugin_get_info (plugin_name, plugin_desc, plugin_version, NULL);
 
@@ -92,7 +91,6 @@ xchat_plugin_init (xchat_plugin * plugin_handle, char **plugin_name, char **plug
 int
 xchat_plugin_deinit (void)
 {
-	gnome_sound_shutdown ();
 	xchat_print (ph, _("Sound-notification plugin unloaded.\n"));
 
 	return 1;
