@@ -33,6 +33,7 @@
 #include "modes.h"
 #include "notify.h"
 #include "plugin.h"
+#include "proto-irc.h"
 #include "server.h"
 #include "text.h"
 #include "outbound.h"
@@ -61,10 +62,10 @@ irc_nickserv (server *serv, char *cmd, char *arg1, char *arg2, char *arg3)
 		tcp_sendf (serv, "PRIVMSG NICKSERV :%s %s%s%s\r\n", cmd, arg1, arg2, arg3);
 		break;
 	case 1:
-		tcp_sendf (serv, "NICKSERV :%s %s%s%s\r\n", cmd, arg1, arg2, arg3);
+		tcp_sendf (serv, "NICKSERV %s %s%s%s\r\n", cmd, arg1, arg2, arg3);
 		break;
 	case 2:
-		tcp_sendf (serv, "NS :%s %s%s%s\r\n", cmd, arg1, arg2, arg3);
+		tcp_sendf (serv, "NS %s %s%s%s\r\n", cmd, arg1, arg2, arg3);
 		break;
 	case 3:
 		tcp_sendf (serv, "PRIVMSG NS :%s %s%s%s\r\n", cmd, arg1, arg2, arg3);
@@ -119,6 +120,8 @@ irc_set_back (server *serv)
 static void
 irc_set_away (server *serv, char *reason)
 {
+	if (!reason[0])
+		reason = " ";
 	tcp_sendf (serv, "AWAY :%s\r\n", reason);
 }
 
@@ -405,6 +408,7 @@ process_numeric (session * sess, int n,
 			}
 
 			serv->skip_next_userhost = FALSE;
+			break;
 		}
 		else goto def;
 
