@@ -86,18 +86,16 @@ static void server_connect (server *serv, char *hostname, int port, int no_login
 
 
 /* actually send to the socket. This might do a character translation or
-   send via SSL */
+   send via SSL. server/dcc both use this function. */
 
-static int
-tcp_send_real (server *serv, char *buf, int len)
+int
+tcp_send_real (void *ssl, int sok, char *encoding, int using_irc, char *buf, int len)
 {
 	int ret;
 	char *locale;
 	gsize loc_len;
 
-	fe_add_rawlog (serv, buf, len, TRUE);
-
-	if (serv->encoding == NULL)	/* system */
+	if (encoding == NULL)	/* system */
 	{
 		locale = NULL;
 		if (!prefs.utf8_locale)
@@ -110,12 +108,12 @@ tcp_send_real (server *serv, char *buf, int len)
 		}
 	} else
 	{
-		if (serv->using_irc)	/* using "IRC" encoding (CP1252/UTF-8 hybrid) */
+		if (using_irc)	/* using "IRC" encoding (CP1252/UTF-8 hybrid) */
 			/* if all chars fit inside CP1252, use that. Otherwise this
 			   returns NULL and we send UTF-8. */
 			locale = g_convert (buf, len, "CP1252", "UTF-8", 0, &loc_len, 0);
 		else
-			locale = g_convert_with_fallback (buf, len, serv->encoding, "UTF-8",
+			locale = g_convert_with_fallback (buf, len, encoding, "UTF-8",
 														 "?", 0, &loc_len, 0);
 	}
 
@@ -123,29 +121,38 @@ tcp_send_real (server *serv, char *buf, int len)
 	{
 		len = loc_len;
 #ifdef USE_OPENSSL
-		if (!serv->ssl)
-			ret = send (serv->sok, locale, len, 0);
+		if (!ssl)
+			ret = send (sok, locale, len, 0);
 		else
-			ret = _SSL_send (serv->ssl, locale, len);
+			ret = _SSL_send (ssl, locale, len);
 #else
-		ret = send (serv->sok, locale, len, 0);
+		ret = send (sok, locale, len, 0);
 #endif
 		g_free (locale);
 	} else
 	{
 #ifdef USE_OPENSSL
-		if (!serv->ssl)
-			ret = send (serv->sok, buf, len, 0);
+		if (!ssl)
+			ret = send (sok, buf, len, 0);
 		else
-			ret = _SSL_send (serv->ssl, buf, len);
+			ret = _SSL_send (ssl, buf, len);
 #else
-		ret = send (serv->sok, buf, len, 0);
+		ret = send (sok, buf, len, 0);
 #endif
 	}
 
 	return ret;
 }
 
+static int
+server_send_real (server *serv, char *buf, int len)
+{
+	fe_add_rawlog (serv, buf, len, TRUE);
+
+	return tcp_send_real (serv->ssl, serv->sok, serv->encoding, serv->using_irc,
+								 buf, len);
+}
+
 /* new throttling system, uses the same method as the Undernet
    ircu2.10 server; under test, a 200-line paste didn't flood
    off the client */
@@ -192,7 +199,7 @@ tcp_send_queue (server *serv)
 				serv->prev_now = now;
 				fe_set_throttle (serv);
 
-				tcp_send_real (serv, buf, len);
+				server_send_real (serv, buf, len);
 
 				buf--;
 				serv->outbound_queue = g_slist_remove (serv->outbound_queue, buf);
@@ -216,7 +223,7 @@ tcp_send_len (server *serv, char *buf, int len)
 	int noqueue = !serv->outbound_queue;
 
 	if (!prefs.throttle)
-		return tcp_send_real (serv, buf, len);
+		return server_send_real (serv, buf, len);
 
 	dbuf = malloc (len + 2);	/* first byte is the priority */
 	dbuf[0] = 2;	/* pri 2 for most things */
@@ -670,16 +677,16 @@ ssl_do_connect (server * serv)
 						 cert_info.algorithm, cert_info.algorithm_bits);
 			EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, buf, NULL, NULL,
 							 NULL, 0);
-			if (cert_info.rsa_tmp_bits)
+			/*if (cert_info.rsa_tmp_bits)
 			{
 				snprintf (buf, sizeof (buf),
 							 "  Public key algorithm uses ephemeral key with %d bits",
 							 cert_info.rsa_tmp_bits);
 				EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, buf, NULL, NULL,
 								 NULL, 0);
-			}
-			snprintf (buf, sizeof (buf), "  Sign algorithm %s (%d bits)",
-						 cert_info.sign_algorithm, cert_info.sign_algorithm_bits);
+			}*/
+			snprintf (buf, sizeof (buf), "  Sign algorithm %s",
+						 cert_info.sign_algorithm/*, cert_info.sign_algorithm_bits*/);
 			EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, buf, NULL, NULL,
 							 NULL, 0);
 			snprintf (buf, sizeof (buf), "  Valid since %s to %s",
@@ -904,7 +911,6 @@ server_read_child (GIOChannel *source, GIOCondition condition, server *serv)
 	char outbuf[512];
 	char host[100];
 	char ip[100];
-	char *p;
 
 	waitline2 (source, tbuf, sizeof tbuf);
 
@@ -1191,8 +1197,8 @@ traverse_socks (int print_fd, int sok, char *serverAddr, int port)
 	if (buf[1] == 90)
 		return 0;
 
-	snprintf (buf, sizeof (buf), "SOCKS\tServer reported error %d,%d.\n", buf[0], buf[1]);
-	proxy_error (print_fd, buf);
+	snprintf ((char *) buf, sizeof ((char *) buf), "SOCKS\tServer reported error %d,%d.\n", buf[0], buf[1]);
+	proxy_error (print_fd, (char *) buf);
 	return 1;
 }
 
@@ -1292,10 +1298,10 @@ traverse_socks5 (int print_fd, int sok, char *serverAddr, int port)
 	if (buf[0] != 5 || buf[1] != 0)
 	{
 		if (buf[1] == 2)
-			snprintf (buf, sizeof (buf), "SOCKS\tProxy refused to connect to host (not allowed).\n");
+			snprintf ((char *) buf, sizeof ((char *) buf), "SOCKS\tProxy refused to connect to host (not allowed).\n");
 		else
-			snprintf (buf, sizeof (buf), "SOCKS\tProxy failed to connect to host (error %d).\n", buf[1]);
-		proxy_error (print_fd, buf);
+			snprintf ((char *) buf, sizeof ((char *) buf), "SOCKS\tProxy failed to connect to host (error %d).\n", buf[1]);
+		proxy_error (print_fd, (char *) buf);
 		return 1;
 	}
 	if (buf[3] == 1)	/* IPV4 32bit address */
@@ -1409,9 +1415,9 @@ http_read_line (int print_fd, int sok, char *buf, int len)
 static int
 traverse_http (int print_fd, int sok, char *serverAddr, int port)
 {
-	char buf[256];
-	char auth_data[128];
-	char auth_data2[68];
+	char buf[512];
+	char auth_data[256];
+	char auth_data2[252];
 	int n, n2;
 
 	n = snprintf (buf, sizeof (buf), "CONNECT %s:%d HTTP/1.0\r\n",
@@ -1824,6 +1830,10 @@ server_set_defaults (server *serv)
 	serv->supports_watch = FALSE;
 	serv->bad_prefix = FALSE;
 	serv->use_who = TRUE;
+	serv->have_namesx = FALSE;
+	serv->have_uhnames = FALSE;
+	serv->have_whox = FALSE;
+	serv->have_capab = FALSE;
 	serv->have_idmsg = FALSE;
 	serv->have_except = FALSE;
 }
