@@ -276,7 +276,6 @@ static const struct defaultserver def[] =
 	{0,				"irc.cs.hut.fi"},
 
 	{"Irctoo.net",	0},
-	{0,			"irc.canadian.net"},
 	{0,			"irc.irctoo.net"},
 
 	{"Krstarica", 0},
@@ -339,8 +338,7 @@ static const struct defaultserver def[] =
 	{0,			"irc.othernet.org"},
 
 	{"OzNet",	0},
-	{0,			"sydney.oz.org"},
-	{0,			"melbourne.oz.org"},
+	{0,			"irc.oz.org"},
 
 	{"PTlink",	0},
 	{0,			"irc.PTlink.net"},
@@ -429,6 +427,9 @@ static const struct defaultserver def[] =
 	{"Sohbet.Net", 0},
 	{0,			"irc.sohbet.net"},
 
+	{"SolidIRC", 0},
+	{0,			"irc.solidirc.com"},
+
 	{"SorceryNet",	0},
 	{0,			"irc.sorcery.net/9000"},
 	{0,			"irc.us.sorcery.net/9000"},
@@ -546,9 +547,6 @@ servlist_connect (session *sess, ircnet *net, gboolean join)
 	serv->network = net;
 
 	port = strrchr (ircserv->hostname, '/');
-	if (!port)
-	    port = strchr (ircserv->hostname, ':');
-	
 	if (port)
 	{
 		*port = 0;
