@@ -22,9 +22,8 @@
 #include <config.h>
 #include <glib/gi18n.h>
 #include <glib.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomeui/gnome-icon-lookup.h>
+#include <gio/gio.h>
+#include <gtk/gtk.h>
 #include "gui.h"
 #include "dcc-window.h"
 #include "util.h"
@@ -102,7 +101,7 @@ dcc_window_init (DccWindow *window)
 	window->transfer_store = gtk_list_store_new (N_COLUMNS,
 	                                             G_TYPE_POINTER,	/* DCC struct */
 	                                             G_TYPE_STRING,	/* Info text */
-	                                             GDK_TYPE_PIXBUF,	/* File icon */
+	                                             G_TYPE_ICON,	/* File icon */
 	                                             G_TYPE_INT,	/* % done */
 	                                             G_TYPE_STRING,	/* % done label */
 	                                             G_TYPE_STRING	/* time remaining */
@@ -128,7 +127,7 @@ dcc_window_init (DccWindow *window)
 
 	window->icon_cell = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_column_pack_start (window->info_column, window->icon_cell, FALSE);
-	gtk_tree_view_column_add_attribute (window->info_column, window->icon_cell, "pixbuf", ICON_COLUMN);
+	gtk_tree_view_column_add_attribute (window->info_column, window->icon_cell, "gicon", ICON_COLUMN);
 
 	window->info_cell = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (window->info_column, window->info_cell, TRUE);
@@ -153,10 +152,6 @@ dcc_window_init (DccWindow *window)
 	gtk_tree_view_append_column (GTK_TREE_VIEW (window->transfer_list), window->info_column);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (window->transfer_list), window->remaining_column);
 
-	GtkIconTheme *theme = gtk_icon_theme_get_default ();
-	window->up_icon   = gtk_icon_theme_load_icon (theme, "go-up",   24, 0, NULL);
-	window->down_icon = gtk_icon_theme_load_icon (theme, "go-down", 24, 0, NULL);
-
 	g_signal_connect (
 		G_OBJECT (gtk_tree_view_get_selection (
 			GTK_TREE_VIEW (window->transfer_list))),
@@ -240,8 +235,8 @@ dcc_window_add (DccWindow *window, struct DCC *dcc)
 	}
 
 	done_text = g_strdup_printf ("%d %%", done);
-	size = gnome_vfs_format_file_size_for_display (dcc->size);
-	pos = gnome_vfs_format_file_size_for_display (dcc->pos);
+	size = g_format_size_for_display (dcc->size);
+	pos = g_format_size_for_display (dcc->pos);
 	info_text = g_strdup_printf (_("<b>%s</b>\n<small>from %s</small>\n%s of %s"), dcc->file, dcc->nick, pos, size);
 	g_free (size);
 	g_free (pos);
@@ -278,9 +273,9 @@ dcc_window_update (DccWindow *window, struct DCC *dcc)
 			if (ptr == dcc) {
 				gint done = (gint) ((((float)dcc->pos) / ((float) dcc->size)) * 100);
 				gchar *done_text = g_strdup_printf ("%d %%", done);
-				gchar *size = gnome_vfs_format_file_size_for_display (dcc->size);
-				gchar *pos = gnome_vfs_format_file_size_for_display (dcc->pos);
-				gchar *speed = gnome_vfs_format_file_size_for_display (dcc->cps);
+				gchar *size = g_format_size_for_display (dcc->size);
+				gchar *pos = g_format_size_for_display (dcc->pos);
+				gchar *speed = g_format_size_for_display (dcc->cps);
 				gchar *info_text;
 				gchar *remaining_text;
 
@@ -331,67 +326,48 @@ dcc_window_update (DccWindow *window, struct DCC *dcc)
 				g_free (remaining_text);
 
 				/* We put off rendering the icon until we get at least one update,
-				 * to ensure that gnome-vfs can determine the MIME type
+				 * to ensure that can determine the MIME type
 				 */
 				if (dcc->destfile != NULL && icon == NULL) {
-					GtkIconTheme *icon_theme;
-					char *icon;
-					char *mime;
-					GdkPixbuf *mime_pixbuf, *file_icon, *direction_emblem;
-					int mime_w, mime_h;
-					gpointer image_data;
+					GFile *file;
+					GFileInfo *info;
+					GIcon *mime_icon, *emblemed_icon, *direction_icon;
+					GEmblem *direction_emblem;
 
 					/* If the file doesn't exist yet, don't do the icon */
 					if (g_file_test (dcc->destfile, G_FILE_TEST_EXISTS) == FALSE) {
 						return;
 					}
 
-					/* Get MIME type from gnome-vfs, create the proper file icon for it. */
-					mime = gnome_vfs_get_mime_type (dcc->destfile);
-					icon_theme = gtk_icon_theme_get_default ();
-					icon = gnome_icon_lookup (icon_theme, NULL, NULL, NULL, NULL, mime, GNOME_ICON_LOOKUP_FLAGS_NONE, NULL);
-					mime_pixbuf = gtk_icon_theme_load_icon (icon_theme, icon, 48, 0, NULL);
+					file = g_file_new_for_path (dcc->destfile);
+					info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_ICON,
+								  0, NULL, NULL);
+					g_object_unref (file);
 
-					mime_w   = gdk_pixbuf_get_width  (mime_pixbuf);
-					mime_h   = gdk_pixbuf_get_height (mime_pixbuf);
+					if (!info) {
+						return;
+					}
 
-					/* Create a new, empty image, 8px bigger than the MIME icon */
-					image_data = g_new0 (char, (mime_w + 8) * (mime_h + 8) * 4 * 8);
-					file_icon = gdk_pixbuf_new_from_data (image_data,
-					                                      GDK_COLORSPACE_RGB, TRUE, 8,
-					                                      mime_w + 8, mime_h + 8, (mime_w + 8) * 4,
-					                                      (GdkPixbufDestroyNotify) g_free, NULL);
-
-					/* Composite on our MIME icon */
-					gdk_pixbuf_composite (mime_pixbuf,
-					                      file_icon,
-					                      0, 0,
-					                      mime_w, mime_h,
-					                      0.0, 0.0,
-					                      1.0, 1.0,
-					                      GDK_INTERP_BILINEAR, 255);
+					mime_icon = g_file_info_get_icon (info);
 
 					/* Composite on an emblem which shows the direction of transfer */
 					if (dcc->type == 1) {
-						direction_emblem = window->down_icon;
+						direction_icon = g_themed_icon_new ("go-down");
 					} else {
-						direction_emblem = window->up_icon;
+						direction_icon = g_themed_icon_new ("go-up");
 					}
 
-					gdk_pixbuf_composite (direction_emblem,
-					                      file_icon,
-					                      mime_w - 16, mime_w - 16,
-					                      24, 24,
-					                      mime_w - 16, mime_w - 16,
-					                      1.0, 1.0,
-					                      GDK_INTERP_BILINEAR, 255);
+					direction_emblem = g_emblem_new (direction_icon);
+					emblemed_icon = g_emblemed_icon_new (mime_icon, direction_emblem);
 
-					g_free (icon);
+					gtk_list_store_set (window->transfer_store, &iter, ICON_COLUMN, emblemed_icon, -1);
 
-					gtk_list_store_set (window->transfer_store, &iter, ICON_COLUMN, file_icon, -1);
+					g_object_unref (mime_icon);
+					g_object_unref (emblemed_icon);
+					g_object_unref (direction_emblem);
+					g_object_unref (direction_icon);
 
-					g_object_unref (mime_pixbuf);
-					g_object_unref (file_icon);
+					g_object_unref (info);
 				}
 
 				return;
