@@ -25,7 +25,7 @@
 #include <glade/glade.h>
 #include <gtk/gtkactiongroup.h>
 #include <gtk/gtkuimanager.h>
-#include <gnome.h>
+#include <libgnome/gnome-program.h>
 #include "userlist.h"
 #include "navigation-tree.h"
 #include "dcc-window.h"
