@@ -49,6 +49,7 @@ static void     join_channel           (GtkAction *action, gpointer data);
 
 static void	on_server_autoconnect  (GtkAction *action, gpointer data);
 static void     on_channel_autojoin (GtkAction *action, gpointer data);
+static void     on_channel_confmode (GtkAction *action, gpointer data);
 
 
 #define NAVTREE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), NAVTREE_TYPE, NavTreePriv))
@@ -86,11 +87,11 @@ static gboolean channel_is_autojoin (session *sess);
 
 /***** Actions *****/
 static GtkActionEntry action_entries[] = {
-	// Go menu
-	{ "GoPreviousNetwork",    NULL, N_("Pre_vious Network"),    "<control>Up",   NULL, G_CALLBACK (go_previous_network) },
-	{ "GoNextNetwork",        NULL, N_("Nex_t Network"),        "<control>Down", NULL, G_CALLBACK (go_next_network) },
-	{ "GoPreviousDiscussion", NULL, N_("_Previous Discussion"), "<alt>Up",       NULL, G_CALLBACK (go_previous_discussion) },
-	{ "GoNextDiscussion",     NULL, N_("_Next Discussion"),     "<alt>Down",     NULL, G_CALLBACK (go_next_discussion) },
+	// View menu
+	{ "ViewPreviousNetwork",    NULL, N_("Pre_vious Network"),    "<control>Up",   NULL, G_CALLBACK (go_previous_network) },
+	{ "ViewNextNetwork",        NULL, N_("Nex_t Network"),        "<control>Down", NULL, G_CALLBACK (go_next_network) },
+	{ "ViewPreviousDiscussion", NULL, N_("_Previous Discussion"), "<alt>Up",       NULL, G_CALLBACK (go_previous_discussion) },
+	{ "ViewNextDiscussion",     NULL, N_("_Next Discussion"),     "<alt>Down",     NULL, G_CALLBACK (go_next_discussion) },
 
 	// Discussion context menu
 	{"DiscussionJoin", GTK_STOCK_JUMP_TO, N_("_Join"), "", NULL, G_CALLBACK (join_channel) },
@@ -101,7 +102,8 @@ static GtkToggleActionEntry toggle_action_entries[] = {
 	{"NetworkAutoConnect", NULL, N_("_Auto-connect on startup"), "", NULL, G_CALLBACK (on_server_autoconnect), FALSE},
 
 	// Discussion context menu
-	{"DiscussionAutoJoin",   NULL, N_("_Auto-join on connect"),    "", NULL, G_CALLBACK (on_channel_autojoin), FALSE}
+	{"DiscussionAutoJoin", NULL, N_("_Auto-join on connect"), "", NULL, G_CALLBACK (on_channel_autojoin), FALSE},
+	{"DiscussionConfMode", NULL, N_("Show join/part messages"), "", NULL, G_CALLBACK (on_channel_confmode), FALSE}
 };
 
 
@@ -298,9 +300,13 @@ selection_changed (GtkTreeSelection *selection, NavTree *tree)
 		if (sess) {
 			fe_set_current (sess);
 
-			GtkAction *action = gtk_action_group_get_action (tree->priv->action_group, "DiscussionAutoJoin");
-			gtk_action_set_sensitive (action, sess->server->network != NULL);
-			gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), channel_is_autojoin (sess));
+			GtkAction *action = gtk_action_group_get_action(tree->priv->action_group, "DiscussionAutoJoin");
+			gtk_action_set_sensitive(action, sess->server->network != NULL);
+			gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), channel_is_autojoin(sess));
+
+			action = gtk_action_group_get_action(tree->priv->action_group, "DiscussionConfMode");
+			gtk_action_set_sensitive(action, sess->server->network != NULL);
+			gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), !sess->hide_join_part);
 
 			ircnet *network = (ircnet*) sess->server->network;
 			if (network != NULL) {
@@ -1119,6 +1125,7 @@ set_action_state (NavTree *navtree)
 	GtkAction *discussion_join         = gtk_ui_manager_get_action (gui.manager, "/ChannelPopup/DiscussionJoin");
 	GtkAction *discussion_leave        = gtk_ui_manager_get_action (gui.manager, "/ChannelPopup/DiscussionLeave");
 	GtkAction *discussion_auto_join    = gtk_ui_manager_get_action (gui.manager, "/ChannelPopup/DiscussionAutoJoin");
+	GtkAction *discussion_conf_mode    = gtk_ui_manager_get_action (gui.manager, "/ChannelPopup/DiscussionConfMode");
 	GtkAction *discussion_change_topic = gtk_ui_manager_get_action (gui.manager, "/menubar/DiscussionMenu/DiscussionChangeTopic");
 	GtkAction *discussion_users        = gtk_ui_manager_get_action (gui.manager, "/menubar/DiscussionMenu/DiscussionUsers");
 	GtkAction *discussion_bans         = gtk_ui_manager_get_action (gui.manager, "/menubar/DiscussionMenu/DiscussionBans");
@@ -1139,6 +1146,7 @@ set_action_state (NavTree *navtree)
 		gtk_action_set_sensitive (discussion_join,         FALSE);
 		gtk_action_set_sensitive (discussion_leave,        FALSE);
 		gtk_action_set_sensitive (discussion_auto_join,    FALSE);
+		gtk_action_set_sensitive (discussion_conf_mode,    FALSE);
 		gtk_action_set_sensitive (discussion_change_topic, FALSE);
 		gtk_action_set_sensitive (discussion_users,        FALSE);
 		gtk_action_set_sensitive (discussion_bans,         FALSE);
@@ -1171,6 +1179,7 @@ set_action_state (NavTree *navtree)
 		gtk_action_set_sensitive (discussion_join,         FALSE);
 		gtk_action_set_sensitive (discussion_leave,        FALSE);
 		gtk_action_set_sensitive (discussion_auto_join,    FALSE);
+		gtk_action_set_sensitive (discussion_conf_mode,    FALSE);
 		gtk_action_set_sensitive (discussion_change_topic, FALSE);
 		gtk_action_set_sensitive (discussion_users,        FALSE);
 		gtk_action_set_sensitive (discussion_bans,         FALSE);
@@ -1190,6 +1199,7 @@ set_action_state (NavTree *navtree)
 		gtk_action_set_sensitive (discussion_join,         (connected == FALSE && sess->server->connected == TRUE));
 		gtk_action_set_sensitive (discussion_leave,        (connected == TRUE));
 		gtk_action_set_sensitive (discussion_auto_join,    TRUE);
+		gtk_action_set_sensitive (discussion_conf_mode,    TRUE);
 		gtk_action_set_sensitive (discussion_change_topic, TRUE);
 		gtk_action_set_sensitive (discussion_users,        TRUE);
 		gtk_action_set_sensitive (discussion_bans,         FALSE);
@@ -1209,6 +1219,7 @@ set_action_state (NavTree *navtree)
 		gtk_action_set_sensitive (discussion_join,         FALSE);
 		gtk_action_set_sensitive (discussion_leave,        FALSE);
 		gtk_action_set_sensitive (discussion_auto_join,    FALSE);
+		gtk_action_set_sensitive (discussion_conf_mode,    FALSE);
 		gtk_action_set_sensitive (discussion_change_topic, FALSE);
 		gtk_action_set_sensitive (discussion_users,        FALSE);
 		gtk_action_set_sensitive (discussion_bans,         FALSE);
@@ -1376,19 +1387,37 @@ set_channel_autojoin (session *sess, gboolean autojoin)
 static void
 on_channel_autojoin (GtkAction *action, gpointer data)
 {
-	gboolean active;
-	session *sess;
 	NavTree *navtree = gui.server_tree;
-	GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (navtree));
+	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(navtree));
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 
-	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-		gtk_tree_model_get (model, &iter, COLUMN_SESSION, &sess, -1);
+	if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
+		session *sess;
+		gtk_tree_model_get(model, &iter, COLUMN_SESSION, &sess, -1);
 
-		g_assert (sess != NULL);
+		g_assert(sess != NULL);
 
-		active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action) );
-		set_channel_autojoin (sess, active);
+		gboolean active = gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(action));
+		set_channel_autojoin(sess, active);
+	}
+}
+
+static void
+on_channel_confmode(GtkAction *action, gpointer data)
+{
+	NavTree *navtree = gui.server_tree;
+	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(navtree));
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+
+	if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
+		session *sess;
+		gtk_tree_model_get(model, &iter, COLUMN_SESSION, &sess, -1);
+
+		g_assert(sess != NULL);
+
+		gboolean active = gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(action));
+		sess->hide_join_part = !active;
 	}
 }
