@@ -153,7 +153,7 @@ gconf_languages_changed (GConfClient *client, guint cnxn_id, GConfEntry *entry,
 				                    COL_LANG_CODE, &lang, -1);
 				active = sexy_spell_entry_language_is_active (SEXY_SPELL_ENTRY (gui.text_entry), lang);
 
-				gtk_list_store_set (store, &iter, COL_LANG_ACTIVATED, !active, -1);
+				gtk_list_store_set (store, &iter, COL_LANG_ACTIVATED, active, -1);
 			} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (store), &iter));
 		}
 	}
